@@ -40,7 +40,7 @@ setenvGDAL <- function(bin_GDAL = NULL) {
 #'@param quiet boolean  switch for supressing console messages default is TRUE
 #'@return A dataframe with the 'GDAL' root folder(s) the version name(s) and the installation type(s).
 #'@author Chris Reudenbach
-#'@export searchGDALW
+#'@export 
 #'@keywords internal
 #'
 #'@examples
@@ -202,76 +202,183 @@ searchGDALW <- function(DL = "C:/", quiet = TRUE) {
   gdal1$py <- gdal_py[gdalInstallations$installation_type != "unknown"]
   return(gdal1)
 }
-#'@title Search recursively for valid 'GDAL' installation(s) on a 'X-based' OS
-#'@name searchGDALX
-#'@description  Search for valid 'GDAL' installations on a 'X-based' OS
-#'@param MP drive letter default is '/usr/bin'
-#'@param quiet boolean  switch for supressing messages default is TRUE
-#'@return A dataframe with the 'GDAL' root folder(s) the version name(s) and the installation type(s).
-#'@author Chris Reudenbach
-#'@export searchGDALX
-#'@keywords internal
+#' Search recursively for valid GDAL installation(s) on Linux/macOS
 #'
-#'@examples
+#' Searches for an executable `gdalinfo` and returns a normalized installations
+#' table plus best-effort lists of GDAL binaries (`gdal*`) and python tools (`*.py`)
+#' found alongside the detected `gdalinfo`.
 #'
-#' run = FALSE
-#' if (run) {
-#' # get all valid GDAL installation folders and params
-#' searchGDALX()
+#' This implementation is portable: it does NOT use GNU-only `find` primaries
+#' such as `-readable`, and it uses `system2(..., args=...)` with proper token
+#' separation (no shell parsing assumptions).
+#'
+#' @param MP Character. Search root. `"default"` expands to `c("~","/opt","/usr/local","/usr")`.
+#'   You may also pass a single directory (e.g. `"/usr"`).
+#' @param quiet Logical. If `TRUE`, suppress messages.
+#'
+#' @return A list with:
+#' \describe{
+#'   \item{gdalInstallations}{data.frame with columns `binDir`, `baseDir`, `installation_type`.}
+#'   \item{bin}{list of data.frames (column `gdal_bin`) with detected GDAL binaries per installation.}
+#'   \item{py}{list of data.frames (column `gdal_py`) with detected GDAL python tools per installation.}
 #' }
-searchGDALX <- function(MP = "/usr/bin", quiet = TRUE) {
-  if (MP == "default")
-    MP <- "/usr/bin"
-  if (!exists("GiEnv"))
-    GiEnv <- new.env(parent = globalenv())
-  # trys to find a osgeo4w installation at the mounting point disk returns root directory and version name recursive
-  # dir for gdal*.bat returns all version of gdal bat files
-  if (!quiet)
-    cat("\nsearching for GDAL Toolbox installations - this may take a while\n")
-  if (!quiet)
-    cat("For providing the path manually see ?searchGDALX \n")
-  raw_GDAL <- options(show.error.messages = FALSE)
-  options(warn = -1)
-  raw_GDAL <- try(system2("find", paste(MP, " ! -readable -prune -o -type f -executable -iname 'gdalinfo' -print"), stdout = TRUE))
-  if (identical(raw_GDAL, character(0)))
-    raw_GDAL <- "File not found"
-  if (grepl(raw_GDAL, pattern = "File not found") | grepl(raw_GDAL, pattern = "Datei nicht gefunden")) {
-    class(raw_GDAL) <- c("try-error", class(raw_GDAL))
-  }
-  options(show.error.messages = TRUE)
-  options(warn = 0)
-  gdal1 <- gdal_py <- gdal_bin <- list()
-  if (class(raw_GDAL)[1] != "try-error") {
-    # if (!grepl(MP,raw_GDAL)) stop('\n At ',MP,' no GDAL installation found') trys to identify valid gdal
-    # installations and their version numbers
-    gdalInstallations <- lapply(seq(length(raw_GDAL)), function(i) {
-      # TODO strip version from GDAL /usr/bin/gdalcli_BandMath -version 'This is the BandMath application,
-      # version 6.0.0'
-      # if the the tag 'OSGEO4W64' exists set installation_type
-      root_dir <- substr(raw_GDAL[i], 1, gregexpr(pattern = "gdalinfo", raw_GDAL[i])[[1]][1] - 1)
-      # put the existing GISBASE directory, version number and installation type in a data frame
-      data.frame(binDir = root_dir, stringsAsFactors = FALSE)
-    })  # end lapply
-    # bind the df lines
-    gdalInstallations <- do.call("rbind", gdalInstallations)
-    for (i in 1:nrow(gdalInstallations)) {
-      gdal_bin[[i]] <- as.data.frame(grep(Sys.glob(file.path(R.utils::getAbsolutePath(gdalInstallations[[1]][i]), "gdal*")),
-                                          pattern = "\\.(py)$", value = TRUE, invert = TRUE))
-      names(gdal_bin[[i]]) <- "gdal_bin"
-      gdal_py[[i]] <- as.data.frame(grep(Sys.glob(file.path(R.utils::getAbsolutePath(gdalInstallations[[1]][i]), "gdal*")),
-                                         pattern = "\\.(py)$", value = TRUE))
-      names(gdal_py[[i]]) <- "gdal_py"
-    }
+#'
+#' @export
+#' @keywords internal
+#'
+#' @examples
+#' \dontrun{
+#' x <- searchGDALX()
+#' x$gdalInstallations
+#' }
+searchGDALX <- function(MP = "default", quiet = TRUE) {
+  
+  # ---- 1) mountpoints / roots ----
+  if (identical(MP, "default")) {
+    MP <- c("~", "/opt", "/usr/local", "/usr")
   } else {
-    if (!quiet)
-      cat("Did not find any valid GDAL installation at mount point", MP)
-    return(gdalInstallations <- FALSE)
+    MP <- as.character(MP)
   }
-  gdal1$gdalInstallations <- gdalInstallations
-  gdal1$bin <- gdal_bin
-  gdal1$py <- gdal_py
-  return(gdal1)
+  
+  MP <- path.expand(MP)
+  MP <- MP[file.exists(MP)]
+  
+  if (!length(MP)) {
+    if (!quiet) message("No valid search mount points.")
+    return(list(
+      gdalInstallations = data.frame(
+        binDir = character(0),
+        baseDir = character(0),
+        installation_type = character(0),
+        stringsAsFactors = FALSE
+      ),
+      bin = list(),
+      py  = list()
+    ))
+  }
+  
+  if (!quiet) {
+    cat("\nsearching for GDAL installations in:\n")
+    cat(paste0(" - ", MP, collapse = "\n"), "\n")
+  }
+  
+  # ---- helpers ----
+  normp <- function(p) normalizePath(p, mustWork = FALSE)
+  
+  # Prefer `gdalinfo` (no extension) on Unix-like systems.
+  # We search for executable files named gdalinfo (case-insensitive).
+  find_gdalinfo <- function(root) {
+    out <- suppressWarnings(try(system2(
+      "find",
+      args   = c(root, "-type", "f", "-executable", "-iname", "gdalinfo", "-print"),
+      stdout = TRUE,
+      stderr = TRUE
+    ), silent = TRUE))
+    
+    if (inherits(out, "try-error") || !length(out)) return(character(0))
+    
+    # Remove common noise; keep real paths only.
+    out <- out[nzchar(trimws(out))]
+    out <- out[!grepl("Permission denied", out, fixed = TRUE)]
+    unique(out)
+  }
+  
+  # Given a gdalinfo path, derive binDir/baseDir and classify type.
+  derive_install_row <- function(gdalinfo_path) {
+    gdalinfo_path <- normp(gdalinfo_path)
+    binDir <- normp(dirname(gdalinfo_path))
+    baseDir <- normp(file.path(binDir, ".."))
+    
+    # Rough classification (best-effort)
+    installation_type <- "system"
+    lp <- tolower(gdalinfo_path)
+    if (grepl("/osgeo4w", lp, fixed = TRUE)) installation_type <- "osgeo4w"
+    if (grepl("/qgis",    lp, fixed = TRUE)) installation_type <- "qgis"
+    if (grepl("/conda",   lp, fixed = TRUE) || grepl("/miniconda", lp, fixed = TRUE)) installation_type <- "conda"
+    if (grepl("/grass",   lp, fixed = TRUE)) installation_type <- "grass"
+    if (grepl("/otb",     lp, fixed = TRUE)) installation_type <- "otb"
+    
+    data.frame(
+      binDir = binDir,
+      baseDir = baseDir,
+      installation_type = installation_type,
+      stringsAsFactors = FALSE
+    )
+  }
+  
+  # List candidate tools in binDir
+  list_bin_and_py <- function(binDir) {
+    binDir <- normp(binDir)
+    
+    # "gdal*" excluding *.py
+    gdal_bins <- character(0)
+    gdal_pys  <- character(0)
+    
+    if (dir.exists(binDir)) {
+      # Use Sys.glob to mimic your legacy behaviour but safely
+      g <- Sys.glob(file.path(binDir, "gdal*"))
+      if (length(g)) {
+        g <- normp(g)
+        gdal_pys  <- g[grepl("\\.py$", g, ignore.case = TRUE)]
+        gdal_bins <- g[!grepl("\\.py$", g, ignore.case = TRUE)]
+      }
+    }
+    
+    list(
+      bin = data.frame(gdal_bin = gdal_bins, stringsAsFactors = FALSE),
+      py  = data.frame(gdal_py  = gdal_pys,  stringsAsFactors = FALSE)
+    )
+  }
+  
+  # ---- 2) collect gdalinfo hits ----
+  hits <- unique(unlist(lapply(MP, find_gdalinfo), use.names = FALSE))
+  
+  if (!length(hits)) {
+    if (!quiet) message("::: NO GDAL installation found in given locations.")
+    return(list(
+      gdalInstallations = data.frame(
+        binDir = character(0),
+        baseDir = character(0),
+        installation_type = character(0),
+        stringsAsFactors = FALSE
+      ),
+      bin = list(),
+      py  = list()
+    ))
+  }
+  
+  # ---- 3) build normalized installations table ----
+  inst_rows <- lapply(hits, derive_install_row)
+  inst_df <- do.call(rbind, inst_rows)
+  
+  # De-duplicate by binDir (multiple gdalinfo in same bin)
+  inst_df <- inst_df[!duplicated(inst_df$binDir), , drop = FALSE]
+  rownames(inst_df) <- seq_len(nrow(inst_df))
+  
+  # ---- 4) collect gdal bin/py lists per installation ----
+  gdal_bin <- vector("list", nrow(inst_df))
+  gdal_py  <- vector("list", nrow(inst_df))
+  
+  for (i in seq_len(nrow(inst_df))) {
+    x <- list_bin_and_py(inst_df$binDir[i])
+    gdal_bin[[i]] <- x$bin
+    gdal_py[[i]]  <- x$py
+  }
+  
+  out <- list(
+    gdalInstallations = inst_df,
+    bin = gdal_bin,
+    py  = gdal_py
+  )
+  
+  if (!quiet) {
+    message("::: Found ", nrow(inst_df), " GDAL installation(s).")
+  }
+  
+  out
 }
+
+
 #'@title Search recursivly existing 'GDAL binaries' installation(s) at a given drive/mountpoint 
 #'@name findGDAL
 #'@description  Provides an  list of valid 'GDAL' installation(s) 
@@ -283,7 +390,7 @@ searchGDALX <- function(MP = "/usr/bin", quiet = TRUE) {
 #'@param quiet boolean  switch for supressing console messages default is TRUE
 #'@return A dataframe with the 'GDAL' root folder(s),  and command line executable(s)
 #'@author Chris Reudenbach
-#'@export findGDAL
+#'@export 
 #'
 #'@examples
 #'
@@ -328,9 +435,11 @@ getrowGDALVer <- function(paths) {
     if (substr(ret, 1, 4) == "GDAL" && length(ret) > 0) {
       tmp <- strsplit(x = ret, split = "GDAL ")[[1]][2]
       tmp2 <- strsplit(x = tmp, split = ", released ")[[1]][1]
-      highestVer <- max(tmp2, highestVer)
+      if (tmp2 > highestVer ){
+        highestVer <- tmp2
+        pathI <- i
+      }
     }
-    pathI <- i
   }
   options(show.error.messages = TRUE)
   options(warn = 0)
@@ -339,4 +448,4 @@ getrowGDALVer <- function(paths) {
 # getGDALVer<- function (paths){ sep = ifelse(Sys.info()['sysname']=='Windows', '\\', '/') scmd =
 # ifelse(Sys.info()['sysname']=='Windows', 'gdalinfo.exe', 'gdalinfo') tmp<- strsplit(x =
 # system(paste0(paste0(shQuote(paths$binDir[i]),sep,scmd),' --version'),intern = TRUE),split = 'GDAL ')[[1]][2]
-# gdalVersion<- strsplit(x = tmp,split = ', released ')[[1]][1] return (gdalVersion) }
\ No newline at end of file
+# gdalVersion<- strsplit(x = tmp,split = ', released ')[[1]][1] return (gdalVersion) }
