@@ -14,7 +14,7 @@
 #' setup_default()
 #' }
 #' @name setup_default
-#' @export setup_default
+#' @export 
 setup_default <- function(default = NULL, new_folder_list = NULL, new_folder_list_name = NULL) {
   # Read master configuration
   setup_default <- yaml::read_yaml(system.file("templates/", "config-default-projects.yml", package = "link2GI"))
@@ -39,7 +39,7 @@ setup_default <- function(default = NULL, new_folder_list = NULL, new_folder_lis
 #'
 #' @return  List with folder paths and names.
 #'
-#' @export createFolders
+#' @export 
 #' @aliases createFolder
 #'
 #' @examples
@@ -119,8 +119,7 @@ createFolders <- function(root_folder, folders, create_folders = TRUE) {
 #'
 #' @name initProj
 #' 
-#' @export initProj
-#'
+#' @export 
 #' @examples
 #' \dontrun{
 #' root_folder <- tempdir() # Mandatory, variable must be in the R environment.
@@ -130,6 +129,17 @@ createFolders <- function(root_folder, folders, create_folders = TRUE) {
 initProj <- function(root_folder = ".", folders = NULL, init_git = NULL, init_renv = NULL, code_subfolder = c("src", "src/functions",
                                                                                                               "src/configs"), global = FALSE, openproject = NULL, newsession = TRUE, standard_setup = "baseSpatial", loc_name = NULL,
                      ymlFN = NULL, appendlibs = NULL, OpenFiles = NULL) {
+  root_folder <- normalizePath(root_folder, winslash = "/", mustWork = FALSE)
+  
+  # If called from inside an existing project and user passes the project name,
+  # this creates root_folder/root_folder. Detect and stop.
+  wd <- normalizePath(getwd(), winslash = "/", mustWork = TRUE)
+  if (identical(wd, root_folder) || identical(file.path(wd, basename(wd)), root_folder)) {
+    stop(
+      "initProj() must not be run from inside an existing project directory.\n",
+      "Use setupProj(root_folder = getwd(), ...) instead."
+    )
+  }
   notes <- TRUE
   if (is.null(init_git))
     init_git <- FALSE
@@ -189,8 +199,9 @@ initProj <- function(root_folder = ".", folders = NULL, init_git = NULL, init_re
   brew::brew(system.file(sprintf("templates/%s.brew", "post-processing"), package = "link2GI"), file.path(dirs$src, "post-processing.R"))
   brew::brew(system.file(sprintf("templates/%s.brew", "config-master-yml"), package = "link2GI"), file.path(dirs$config,
                                                                                                             "config-master.yml"))
-  brew::brew(system.file(sprintf("templates/%s.brew", standard_setup), package = "link2GI"), file.path(dirs$functions,
-                                                                                                       "000_setup.R"))
+  template_path <- system.file("templates/script_setup.brew", package = "link2GI")
+  brew::brew(template_path, file.path(dirs$functions, "000_setup.R"))
+  
   brew::brew(system.file(sprintf("templates/%s.brew", "yml"), package = "link2GI"), file.path(dirs$config, "pre-processing.yml"))
   brew::brew(system.file(sprintf("templates/%s.brew", "yml"), package = "link2GI"), file.path(dirs$config, "processing.yml"))
   brew::brew(system.file(sprintf("templates/%s.brew", "yml"), package = "link2GI"), file.path(dirs$config, "post-processing.yml"))
@@ -239,9 +250,7 @@ initProj <- function(root_folder = ".", folders = NULL, init_git = NULL, init_re
 #'
 #' @name setupProj
 #' 
-#' @export setupProj
-#'
-#'
+#' @export 
 #' @examples
 #' \dontrun{
 #' setupProj(
@@ -388,8 +397,7 @@ sourceFunctions <- function(fcts_folder, setup_script) {
 #' @return NULL
 #'
 #' @name saveEnvi
-#' @export saveEnvi
-#'
+#' @export 
 #' @examples
 #' \dontrun{
 #' a <- 1
@@ -432,8 +440,7 @@ createMeta <- function(prj_name) {
 #' @return list of 2 containing data and metadata.
 #'
 #' @name loadEnvi
-#' @export loadEnvi
-#'
+#' @export
 #' @examples
 #' \dontrun{
 #' a <- 1
