@@ -6,7 +6,7 @@
 #'@return A data frame containing the 'SAGA GIS' root folder(s), the version name(s) and the installation type(s)
 #'@author Chris Reudenbach
 #'@keywords internal
-#'@export searchSAGAX
+#'@export 
 #'
 #'@examples
 #' \dontrun{
@@ -68,7 +68,7 @@ searchSAGAX <- function(MP = "/usr/bin", quiet = TRUE) {
 #'@return A data frame containing the 'SAGA GIS' root folder(s), the version name(s) and the installation type(s)
 #'@author Chris Reudenbach
 #'@keywords internal
-#'@export searchSAGAW
+#'@export 
 #'
 #'@examples
 #' \dontrun{
@@ -180,7 +180,7 @@ searchSAGAW <- function(DL = "C:/", quiet = TRUE) {
 #'@return A dataframe with the 'SAGA GIS' root folder(s), version name(s) and 
 #'installation type code(s)
 #'@author Chris Reudenbach
-#'@export findSAGA
+#'@export
 #'
 #'@examples
 #' \dontrun{
@@ -193,7 +193,7 @@ findSAGA <- function(searchLocation = "default", quiet = TRUE) {
     if (searchLocation == "default") {
       searchLocation <- "C:/"
     } else {
-      searchLocation <- normalizePath(searchLocation)
+      searchLocation <- normalizePath(searchLocation, mustWork = FALSE)
     }
     if (grepl(paste0(LETTERS, ":", collapse = "|"), substr(toupper(searchLocation), start = 1, stop = 2))) {
       link <- link2GI::searchSAGAW(DL = searchLocation, quiet = quiet)
